@@ -59,7 +59,7 @@ __all__ = ("DynamoDBServiceResource", "Table", "ServiceResourceTablesCollection"
 
 class ServiceResourceTablesCollection(ResourceCollection):
     """
-    [ServiceResource.tables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
+    [ServiceResource.tables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
     """
 
     def all(self) -> "ServiceResourceTablesCollection":
@@ -85,7 +85,7 @@ class ServiceResourceTablesCollection(ResourceCollection):
 
 class Table(Boto3ServiceResource):
     """
-    [Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+    [Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
     """
 
     attribute_definitions: List[Any]
@@ -113,12 +113,12 @@ class Table(Boto3ServiceResource):
 
     def batch_writer(self, overwrite_by_pkeys: List[str] = None) -> BatchWriter:
         """
-        [Table.batch_writer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
+        [Table.batch_writer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
         """
 
     def delete(self) -> DeleteTableOutputTypeDef:
         """
-        [Table.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.delete)
+        [Table.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.delete)
         """
 
     def delete_item(
@@ -170,12 +170,12 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> DeleteItemOutputTypeDef:
         """
-        [Table.delete_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
+        [Table.delete_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Table.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
+        [Table.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
         """
 
     def get_item(
@@ -206,12 +206,12 @@ class Table(Boto3ServiceResource):
         ExpressionAttributeNames: Dict[str, str] = None,
     ) -> GetItemOutputTypeDef:
         """
-        [Table.get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.get_item)
+        [Table.get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.get_item)
         """
 
     def load(self) -> None:
         """
-        [Table.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.load)
+        [Table.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.load)
         """
 
     def put_item(
@@ -263,7 +263,7 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> PutItemOutputTypeDef:
         """
-        [Table.put_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.put_item)
+        [Table.put_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.put_item)
         """
 
     def query(
@@ -324,12 +324,12 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> QueryOutputTypeDef:
         """
-        [Table.query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.query)
+        [Table.query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.query)
         """
 
     def reload(self) -> None:
         """
-        [Table.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.reload)
+        [Table.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.reload)
         """
 
     def scan(
@@ -389,21 +389,21 @@ class Table(Boto3ServiceResource):
         ConsistentRead: bool = None,
     ) -> ScanOutputTypeDef:
         """
-        [Table.scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.scan)
+        [Table.scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.scan)
         """
 
     def update(
         self,
-        AttributeDefinitions: List[AttributeDefinitionTypeDef] = None,
+        AttributeDefinitions: List["AttributeDefinitionTypeDef"] = None,
         BillingMode: Literal["PROVISIONED", "PAY_PER_REQUEST"] = None,
-        ProvisionedThroughput: ProvisionedThroughputTypeDef = None,
+        ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
         GlobalSecondaryIndexUpdates: List[GlobalSecondaryIndexUpdateTypeDef] = None,
-        StreamSpecification: StreamSpecificationTypeDef = None,
+        StreamSpecification: "StreamSpecificationTypeDef" = None,
         SSESpecification: SSESpecificationTypeDef = None,
         ReplicaUpdates: List[ReplicationGroupUpdateTypeDef] = None,
     ) -> "Table":
         """
-        [Table.update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.update)
+        [Table.update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.update)
         """
 
     def update_item(
@@ -457,17 +457,17 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> UpdateItemOutputTypeDef:
         """
-        [Table.update_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.update_item)
+        [Table.update_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.update_item)
         """
 
     def wait_until_exists(self) -> None:
         """
-        [Table.wait_until_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
+        [Table.wait_until_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
         """
 
     def wait_until_not_exists(self) -> None:
         """
-        [Table.wait_until_not_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
+        [Table.wait_until_not_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
         """
 
 
@@ -476,53 +476,53 @@ _Table = Table
 
 class DynamoDBServiceResource(Boto3ServiceResource):
     """
-    [DynamoDB.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.ServiceResource)
+    [DynamoDB.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.ServiceResource)
     """
 
     tables: ServiceResourceTablesCollection
 
     def Table(self, name: str) -> _Table:
         """
-        [ServiceResource.Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+        [ServiceResource.Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
         """
 
     def batch_get_item(
         self,
-        RequestItems: Dict[str, KeysAndAttributesTypeDef],
+        RequestItems: Dict[str, "KeysAndAttributesTypeDef"],
         ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
     ) -> BatchGetItemOutputTypeDef:
         """
-        [ServiceResource.batch_get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
+        [ServiceResource.batch_get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
         """
 
     def batch_write_item(
         self,
-        RequestItems: Dict[str, List[WriteRequestTypeDef]],
+        RequestItems: Dict[str, List["WriteRequestTypeDef"]],
         ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
         ReturnItemCollectionMetrics: Literal["SIZE", "NONE"] = None,
     ) -> BatchWriteItemOutputTypeDef:
         """
-        [ServiceResource.batch_write_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
+        [ServiceResource.batch_write_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
         """
 
     def create_table(
         self,
-        AttributeDefinitions: List[AttributeDefinitionTypeDef],
+        AttributeDefinitions: List["AttributeDefinitionTypeDef"],
         TableName: str,
-        KeySchema: List[KeySchemaElementTypeDef],
+        KeySchema: List["KeySchemaElementTypeDef"],
         LocalSecondaryIndexes: List[LocalSecondaryIndexTypeDef] = None,
         GlobalSecondaryIndexes: List[GlobalSecondaryIndexTypeDef] = None,
         BillingMode: Literal["PROVISIONED", "PAY_PER_REQUEST"] = None,
-        ProvisionedThroughput: ProvisionedThroughputTypeDef = None,
-        StreamSpecification: StreamSpecificationTypeDef = None,
+        ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
+        StreamSpecification: "StreamSpecificationTypeDef" = None,
         SSESpecification: SSESpecificationTypeDef = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> _Table:
         """
-        [ServiceResource.create_table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
+        [ServiceResource.create_table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
+        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
         """
